﻿using NuGet.Server;
using NuGet.Server.Infrastructure;
using NuGet.Server.V2;
using System;
using System.Configuration;
using System.Net.Http;
using System.Web.Http;
using System.Web.Http.ExceptionHandling;
using System.Web.Http.Routing;
using System.Web.Http.SelfHost;

[assembly: WebActivatorEx.PreApplicationStartMethod(typeof(NuGet.PrivateServer.Program), "Start")]
namespace NuGet.PrivateServer
{
    class Program
    {
        private static HttpSelfHostConfiguration _config;

        static void Main(string[] args)
        {

            var port = ConfigurationManager.AppSettings["port"];
            Initialize(port);
            
            using (HttpSelfHostServer server = new HttpSelfHostServer(_config))
            {
                server.OpenAsync().Wait();
                Console.WriteLine($"server listening {port}...");
                Console.WriteLine("press any key to quit.");
                Console.ReadLine();
            }
        }

        private static void Initialize(string port)
        {
            ServiceResolver.SetServiceResolver(new DefaultServiceResolver());

            _config = new HttpSelfHostConfiguration($"http://localhost:{port}");

            NuGetV2WebApiEnabler.UseNuGetV2WebApiFeed(_config, "NuGetDefault", "nuget", "PackagesOData");

            _config.Services.Replace(typeof(IExceptionLogger), new TraceExceptionLogger());

            // Trace.Listeners.Add(new TextWriterTraceListener(HostingEnvironment.MapPath("~/NuGet.Server.log")));
            // Trace.AutoFlush = true;

            _config.Routes.MapHttpRoute(
                name: "NuGetDefault_ClearCache",
                routeTemplate: "nuget/clear-cache",
                defaults: new { controller = "PackagesOData", action = "ClearCache" },
                constraints: new { httpMethod = new HttpMethodConstraint(HttpMethod.Get) }
            );

            _config.Routes.MapHttpRoute(
                "API Default",
                "api/{controller}/{id}",
                new { id = RouteParameter.Optional });
        }
    }
}
